@@ -326,6 +326,10 @@ pub enum ImageErrorKind {
     TooBigWidth(u32),
     #[error("Height is too big: {0}, max is {}", i32::MAX)]
     TooBigHeight(u32),
+    #[error("Zero width not allowed")]
+    ZeroWidth,
+    #[error("Zero height not allowed")]
+    ZeroHeight,
 }
 
 #[derive(Error, Debug)]
@@ -363,6 +367,12 @@ impl CheckData for CompressedData<RgbaImage, ImageLoadInfo> {
             if image.height() > i32::MAX.try_to::<u32>() {
                 Err(TooBigHeight(image.height()))?;
             }
+            if image.width() == 0 {
+                Err(ZeroWidth)?;
+            }
+            if image.height() == 0 {
+                Err(ZeroHeight)?;
+            }
         }
         Ok(())
     }
@@ -1290,6 +1300,8 @@ pub enum SoundErrorKind {
     NameSanitization(#[from] SanitizationError),
     #[error("{0}")]
     Compressed(#[from] CompressedSoundError),
+    #[error("Invalid sound data: {0}")]
+    Opus(#[from] opus_headers::ParseError),
 }
 
 #[derive(Error, Debug)]
@@ -1313,6 +1325,9 @@ impl CheckData for CompressedData<Vec<u8>, ()> {
     type CompressedErrorKind = CompressedSoundError;
 
     fn check_loaded_data(&self) -> Result<(), SoundErrorKind> {
+        if let CompressedData::Loaded(buf) = self {
+            opus_headers::parse_from_read(&buf[..])?;
+        }
         Ok(())
     }
 
