@@ -79,6 +79,21 @@ impl TwMap {
     }
 }
 
+impl Sound {
+    pub fn from_file<P: AsRef<Path>>(path: P) -> Result<Sound, opus_headers::ParseError> {
+        let path = path.as_ref();
+        let name = path.file_stem().unwrap().to_str()
+            .ok_or(io::Error::new(io::ErrorKind::InvalidInput, "The file name includes invalid utf-8"))?
+            .to_owned();
+        let buf = std::fs::read(path)?;
+        opus_headers::parse_from_read(&buf[..])?;
+        Ok(Sound {
+            name,
+            data: buf.into(),
+        })
+    }
+}
+
 impl EmbeddedImage {
     /// Creates a embedded image using a provided image file.
     /// This function supports many more formats than just png.
@@ -636,12 +651,12 @@ fn extend_ndarray<T: Default + Copy>(ndarray: &Array2<T>, up: usize, down: usize
         (ndarray.column(old_width - 1), (up..up + old_height, left + old_width..new_width)), // right edge
     ];
     for (edge, (y_slice, x_slice)) in vertical_edge_ranges {
-        new_ndarray.slice_mut(s![y_slice, x_slice]).genrows_mut()
+        new_ndarray.slice_mut(s![y_slice, x_slice]).rows_mut()
             .into_iter()
             .for_each(|mut row| row.assign(&edge))
     }
     for (edge, (y_slice, x_slice)) in horizontal_edge_ranges {
-        new_ndarray.slice_mut(s![y_slice, x_slice]).gencolumns_mut()
+        new_ndarray.slice_mut(s![y_slice, x_slice]).columns_mut()
             .into_iter()
             .for_each(|mut row| row.assign(&edge))
     }
@@ -770,7 +785,7 @@ impl Layer {
 // For every direction, this function will return the amount of rows/columns that are duplicates of the innermost one
 // Use this function with caution, since for example layers with the same tile everywhere can be shrunken into nothingness in each direction
 fn lossless_shrink_distances<T: Default + Clone + PartialEq>(ndarray: &Array2<T>) -> (usize, usize, usize, usize) {
-    let rows: Vec<_> = ndarray.genrows()
+    let rows: Vec<_> = ndarray.rows()
         .into_iter()
         .collect();
     let up = match rows.windows(2)
@@ -784,7 +799,7 @@ fn lossless_shrink_distances<T: Default + Clone + PartialEq>(ndarray: &Array2<T>
         None => ndarray.nrows(),
     };
 
-    let columns: Vec<_> = ndarray.gencolumns()
+    let columns: Vec<_> = ndarray.columns()
         .into_iter()
         .collect();
     let left = match columns.windows(2)
