@@ -202,6 +202,58 @@ impl Layer {
     }
 }
 
+impl Quad {
+    /// Creates a quad with the center at (0, 0)
+    /// Except for the size, it uses the default values of a newly created quad in the editor
+    pub fn new(width: i32, height: i32) -> Self {
+        Quad {
+            corners: [
+                Point { x: -(width / 2), y: -(height / 2) },
+                Point { x: width / 2, y: -(height / 2) },
+                Point { x: -(width / 2), y: height / 2 },
+                Point { x: width / 2, y: height / 2 },
+            ],
+            position: Point { x: 0, y: 0 },
+            colors: <[Color; 4]>::default(),
+            texture_coords: [
+                Point { x: 0, y: 0 },
+                Point { x: 1024, y: 0 },
+                Point { x: 0, y: 1024 },
+                Point { x: 1024, y: 1024 },
+            ],
+            position_env: None,
+            position_env_offset: 0,
+            color_env: None,
+            color_env_offset: 0
+        }
+    }
+}
+
+impl Default for Quad {
+    /// Default settings of a newly created sound source in the editor
+    fn default() -> Self {
+        Quad::new(1024 * 32 * 2, 1024 * 32 * 2)
+    }
+}
+
+impl Default for SoundSource {
+    /// Default settings of a newly created sound source in the editor
+    fn default() -> Self {
+        SoundSource {
+            position: Point { x: 0, y: 0 },
+            looping: true,
+            panning: true,
+            delay: 0,
+            falloff: 80,
+            position_env: None,
+            position_env_offset: 0,
+            sound_env: None,
+            sound_env_offset: 0,
+            shape: SoundShape::Circle { radius: 1500 },
+        }
+    }
+}
+
 impl<T, U> From<T> for CompressedData<T, U> {
     fn from(data: T) -> Self {
         CompressedData::Loaded(data)
@@ -256,6 +308,12 @@ impl Envelope {
     }
 }
 
+impl<T> Default for CurveKind<T> {
+    fn default() -> Self {
+        CurveKind::Linear
+    }
+}
+
 impl Default for Group {
     fn default() -> Self {
         Group {
@@ -408,6 +466,31 @@ impl Default for I32Color {
     }
 }
 
+impl BezierDefault for I32Color {
+    fn bezier_default() -> Self {
+        I32Color {
+            r: 0,
+            g: 0,
+            b: 0,
+            a: 0,
+        }
+    }
+}
+
+impl Default for Position {
+    fn default() -> Self {
+        Position {
+            x: 0,
+            y: 0,
+            rotation: 0
+        }
+    }
+}
+
+impl BezierDefault for Position {}
+
+impl BezierDefault for i32 {}
+
 impl TileMapLayer for TilesLayer {
     type TileType = Tile;
 
